Module code

Module code 

Structs

FileMarkers
LineGuide
The line guide is useful to locate some positions inside the source code by using the index instead of line and column information.
Point
SortedMarkers
This structure contains all markers sorted by lines and column for each one of the files.
Spaces

Functions

count_width
group_marker_lines
group_markers