LineGuide

Struct LineGuide 

pub struct LineGuide(/* private fields */);
The line guide is useful to locate some positions inside the source code by using the index instead of line and column information.

Implementations

Source

impl LineGuide

pub fn get(code: &str) -> LineGuide

pub fn find(&self, pos: Pos) -> Point

pub fn len(&self) -> usize