Structs
- File
Markers - Line
Guide - The line guide is useful to locate some positions inside the source code by using the index instead of line and column information.
- Point
- Sorted
Markers - This structure contains all markers sorted by lines and column for each one of the files.
- Spaces