pub struct LineGuide(/* private fields */);Expand description
The line guide is useful to locate some positions inside the source code by using the index instead of line and column information.
Implementations